'use strict';

exports.__esModule = true;

var _nodeBuilder = require('../node-builder');

var _internalLiteral = require('../internal-literal');

var _internalLiteral2 = _interopRequireDefault(_internalLiteral);

var _esotope = require('../tools/esotope');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function isDocumentWriteStmt(stmt) {
    return stmt.type === _esotope.Syntax.ExpressionStatement && stmt.expression.type === _esotope.Syntax.CallExpression && stmt.expression.callee.type === _esotope.Syntax.MemberExpression && (stmt.expression.callee.property.name === 'write' || stmt.expression.callee.property.name === 'writeln');
} // -------------------------------------------------------------
// WARNING: this file is used by both the client and the server.
// Do not use any browser or node-specific API!
// -------------------------------------------------------------

function getDocumentWriteStmtIndices(stmts) {
    var indices = [];

    for (var i = 0; i < stmts.length; i++) {
        if (isDocumentWriteStmt(stmts[i])) indices.push(i);
    }

    return indices;
}

// Transform:

// obj.write(html); obj.writeln(html);  -->
// obj.write(html, __begin$); obj.writeln(html, __end$);

exports.default = {
    nodeReplacementRequireTransform: false,

    nodeTypes: [_esotope.Syntax.BlockStatement, _esotope.Syntax.Program],

    condition: function condition(node) {
        return getDocumentWriteStmtIndices(node.body).length > 1;
    },

    run: function run(node) {
        var indices = getDocumentWriteStmtIndices(node.body);
        var firstExpr = node.body[indices[0]].expression;
        var lastExpr = node.body[indices[indices.length - 1]].expression;

        firstExpr.arguments.push((0, _nodeBuilder.createStringLiteral)(_internalLiteral2.default.documentWriteBegin));
        lastExpr.arguments.push((0, _nodeBuilder.createStringLiteral)(_internalLiteral2.default.documentWriteEnd));

        return null;
    }
};
module.exports = exports['default'];