'use strict';

exports.__esModule = true;

var _nodeBuilder = require('../node-builder');

var _esotope = require('../tools/esotope');

// -------------------------------------------------------------
// WARNING: this file is used by both the client and the server.
// Do not use any browser or node-specific API!
// -------------------------------------------------------------

var INVOCATION_FUNC_NAME_RE = /^(call|apply)$/;

// Transform:
// eval.call(ctx, script);
// eval.apply(ctx, script); -->
// eval.call(ctx, __proc$Script(script));
// eval.apply(ctx, __proc$Script(script, true));

exports.default = {
    nodeReplacementRequireTransform: false,

    nodeTypes: [_esotope.Syntax.CallExpression],

    condition: function condition(node) {
        // eval.<meth>(ctx, script, ...)
        if (node.arguments.length < 2) return false;

        if (node.callee.type === _esotope.Syntax.MemberExpression && INVOCATION_FUNC_NAME_RE.test(node.callee.property.name)) {
            var obj = node.callee.object;

            // obj.eval.<meth>(), obj[eval].<meth>(),
            if (obj.type === _esotope.Syntax.MemberExpression && (obj.property.value || obj.property.name) === 'eval') return true;

            // eval.<meth>()
            if (obj.name === 'eval') return true;
        }

        return false;
    },

    run: function run(node) {
        var isApply = node.callee.property.name === 'apply';

        node.arguments[1] = (0, _nodeBuilder.createProcessScriptMethCall)(node.arguments[1], isApply);

        return null;
    }
};
module.exports = exports['default'];